@@ -1,3 +1,11 @@
+__author__ = "Myron Walker"
+__copyright__ = "Copyright 2020, Myron W Walker"
+__credits__ = []
+__version__ = "1.0.0"
+__maintainer__ = "Myron Walker"
+__email__ = "myron.walker@gmail.com"
+__status__ = "Development" # Prototype, Development or Production
+__license__ = "MIT"
 
 from typing import Any, List
 
@@ -23,6 +31,17 @@ class Constraints(FeatureMask):
         inst = dict(self)
         inst.update(kwargs)
         return inst
+    
+    def __repr__(self):
+        this_type = type(self)
+        dict_repr = super().__repr__()
+        repr_str = "{}(**{})".format(this_type.__name__, dict_repr)
+        return repr_str
+
+    def get_import_statement(self):
+        this_type = type(self)
+        import_statement = "from {} import {}".format(this_type.__module__, this_type.__name__)
+        return import_statement
 
 def merge_constraints(*args: Constraints) -> Constraints:
     """
